@@ -36,6 +36,13 @@ class SchedulerAPI(ExposedAPI):
             raise xmlrpclib.Fault(404, "Specified device type not found.")
         return job.id
 
+    def resubmit_job(self, job_id):
+        try:
+            job = TestJob.objects.accessible_by_principal(self.user).get(pk=job_id)
+        except TestJob.DoesNotExist:
+            raise xmlrpclib.Fault(404, "Specified job not found.")
+        return self.submit_job(job.definition)
+
     def cancel_job(self, job_id):
         if not self.user:
             raise xmlrpclib.Fault(401, "Authentication required.")
